aboutsummaryrefslogtreecommitdiffstats
path: root/boards/base/RaspberryPi/FreeRTOS/uart.h
diff options
context:
space:
mode:
Diffstat (limited to 'boards/base/RaspberryPi/FreeRTOS/uart.h')
-rw-r--r--boards/base/RaspberryPi/FreeRTOS/uart.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/boards/base/RaspberryPi/FreeRTOS/uart.h b/boards/base/RaspberryPi/FreeRTOS/uart.h
index fe7f64aa..ca9f377e 100644
--- a/boards/base/RaspberryPi/FreeRTOS/uart.h
+++ b/boards/base/RaspberryPi/FreeRTOS/uart.h
@@ -12,9 +12,9 @@ void uart_init();
/*
* Transmit a byte via UART0.
* uint8_t Byte: byte to send.
*/
-void uart_putc(uint8_t byte);
+void uart_putc(gU8 byte);
/*
* print a string to the UART one character at a time
@@ -12,9 +12,9 @@ void uart_init();
/*
* Transmit a byte via UART0.
- * uint8_t Byte: byte to send.
+ * gU8 Byte: byte to send.
*/